==> makumba-0_5_9_14-src.zip: makumba/classes/org/makumba/controller/html/charEnumEditor.java <==
///////////////////////////////
//  Makumba, Makumba tag library
//  Copyright (C) 2000-2003  http://www.makumba.org
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
//
//  -------------
//  $Id: charEnumEditor.java,v 2.3 2003/09/16 19:09:51 fred Exp $
//  $Name: makumba-0_5_9_14 $
/////////////////////////////////////

package org.makumba.controller.html;
import org.makumba.view.*;
import javax.servlet.*;
import java.util.*;

public class charEnumEditor extends FieldEditor
{
  public String formatShow(Object o, Dictionary formatParams)
  {
    // check if the value is to be replaced by 'default' or 'empty'.
    o = formatValue(o, formatParams) ;
  	
    StringBuffer sb=new StringBuffer();
    sb.append("<select name=\"").append(getInputName(formatParams))
      .append("\"").append(getExtraFormatting(formatParams)).append(">");
    Enumeration n=getNames();
    while(n.hasMoreElements())
      {
	Object nl=n.nextElement();
	sb.append("<option value=\"").append(nl).append("\"");
	if(nl.equals(o))
	  sb.append(" selected");
	sb.append(">").append(nl).append("</option>");
      }
    sb.append("</select>");
    return sb.toString();
  }
}

==> makumba-0_5_9_15-src.zip: makumba/classes/org/makumba/controller/html/charEnumEditor.java <==
///////////////////////////////
//  Makumba, Makumba tag library
//  Copyright (C) 2000-2003  http://www.makumba.org
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
//
//  -------------
//  $Id: charEnumEditor.java,v 2.4 2003/09/21 12:37:30 fred Exp $
//  $Name: makumba-0_5_9_15 $
/////////////////////////////////////

package org.makumba.controller.html;
import org.makumba.view.*;
import javax.servlet.*;
import java.util.*;

public class charEnumEditor extends choiceEditor{

  public Object getOptions(){return null; }

  public int getOptionsLength(Object opts){ return getEnumeratorSize(); }

  public Object getOptionValue(Object options, int i)
  { return getStringAt(i); }

  public String formatOptionValue(Object val)
  { return val.toString(); }

  public String formatOptionValue(Object opts, int i, Object val)
  { return val.toString(); }
  
  public String formatOptionTitle(Object options, int i)
  { return getNameAt(i); } 

  public String getMultiple() { return ""; }
  public boolean isMultiple() { return false; }

  public int getDefaultSize() { return 1; }
	
	
  public String formatShowHIDE(Object o, Dictionary formatParams)
  {
    // check if the value is to be replaced by 'default' or 'empty'.
    o = formatValue(o, formatParams) ;
  	
    StringBuffer sb=new StringBuffer();
    sb.append("<select name=\"").append(getInputName(formatParams))
      .append("\"").append(getExtraFormatting(formatParams)).append(">");
    Enumeration n=getNames();
    while(n.hasMoreElements())
      {
	Object nl=n.nextElement();
	sb.append("<option value=\"").append(nl).append("\"");
	if(nl.equals(o))
	  sb.append(" selected");
	sb.append(">").append(nl).append("</option>");
      }
    sb.append("</select>");
    return sb.toString();
  }
}
